@@ -8,11 +8,12 @@ import numpy as np
 from scipy.stats import spearmanr
 from scipy.stats import pearsonr
 from scipy.stats import kendalltau
+from neurora.stuff import permutation_corr
 
 
 ' a function for calculating the Spearman correlation coefficient between two RDMs '
 
-def rdm_correlation_spearman(RDM1, RDM2, rescale=False):
+def rdm_correlation_spearman(RDM1, RDM2, rescale=False, permutation=False, iter=5000):
 
     """
     Calculate the Spearman Correlation between two RDMs
@@ -30,6 +31,10 @@ def rdm_correlation_spearman(RDM1, RDM2, rescale=False):
     rescale : bool True or False. Default is False.
         Rescale the values in RDM or not.
         Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
+    permutation : bool True or False. Default is False.
+        Use permutation test or not.
+    iter : int. Default is 5000.
+        The times for iteration.
 
     Returns
     -------
@@ -108,12 +113,18 @@ def rdm_correlation_spearman(RDM1, RDM2, rescale=False):
     print(v2)
 
     # calculate the Spearman Correlation
-    return spearmanr(v1, v2)
+    rp = np.array(spearmanr(v1, v2))
+
+    if permutation == True:
+
+        rp[1] = permutation_corr(v1, v2, method="spearman", iter=iter)
+
+    return rp
 
 
 ' a function for calculating the Pearson correlation coefficient between two RDMs '
 
-def rdm_correlation_pearson(RDM1, RDM2, rescale=False):
+def rdm_correlation_pearson(RDM1, RDM2, rescale=False, permutation=False):
 
     """
     Calculate the Pearson Correlation between two RDMs
@@ -131,6 +142,10 @@ def rdm_correlation_pearson(RDM1, RDM2, rescale=False):
     rescale : bool True or False. Default is False.
         Rescale the values in RDM or not.
         Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
+    permutation : bool True or False. Default is False.
+        Use permutation test or not.
+    iter : int. Default is 5000.
+        The times for iteration.
 
     Returns
     -------
@@ -200,13 +215,19 @@ def rdm_correlation_pearson(RDM1, RDM2, rescale=False):
             v2[nn] = RDM2[i, i + j + 1]
             nn = nn + 1
 
-    # calculate the Pearson Correlation
-    return pearsonr(v1, v2)
+    # calculate the Spearman Correlation
+    rp = np.array(pearsonr(v1, v2))
+
+    if permutation == True:
+
+        rp[1] = permutation_corr(v1, v2, method="pearson", iter=iter)
+
+    return rp
 
 
 ' a function for calculating the Kendalls tau correlation coefficient between two RDMs '
 
-def rdm_correlation_kendall(RDM1, RDM2, rescale=False):
+def rdm_correlation_kendall(RDM1, RDM2, rescale=False, permutation=True):
 
     """
     Calculate the Kendalls tau Correlation between two RDMs
@@ -224,6 +245,10 @@ def rdm_correlation_kendall(RDM1, RDM2, rescale=False):
     rescale : bool True or False. Default is False.
         Rescale the values in RDM or not.
         Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
+    permutation : bool True or False. Default is False.
+        Use permutation test or not.
+    iter : int. Default is 5000.
+        The times for iteration.
 
     Returns
     -------
@@ -294,8 +319,14 @@ def rdm_correlation_kendall(RDM1, RDM2, rescale=False):
             v2[nn] = RDM2[i, i + j + 1]
             nn = nn + 1
 
-    # calculate the Kendall tau Correlation
-    return kendalltau(v1, v2)
+    # calculate the Kendalltau Correlation
+    rp = np.array(kendalltau(v1, v2))
+
+    if permutation == True:
+
+        rp[1] = permutation_corr(v1, v2, method="kendalltau", iter=iter)
+
+    return rp
 
 
 ' a function for calculating the Cosine Similarity between two RDMs '
@@ -493,122 +524,3 @@ def rdm_distance(RDM1, RDM2, rescale=False):
     dist = np.linalg.norm(v1 - v2)
 
     return dist
-
-
-' a function for permutation test between two RDMs '
-
-def rdm_permutation(RDM1, RDM2, iter=1000, rescale=False):
-
-    """
-    Conduct Permutation test between two RDMs
-
-    Parameters
-    ----------
-    RDM1 : array [ncons, ncons]
-        The RDM 1.
-        The shape of RDM1 must be [n_cons, n_cons].
-        n_cons represent the number of conidtions.
-    RDM2 : array [ncons, ncons].
-        The RDM 2.
-        The shape of RDM2 must be [n_cons, n_cons].
-        n_cons represent the number of conidtions.
-    iter : int. Default is 1000.
-        The times for iteration.
-    rescale : bool True or False. Default is False.
-        Rescale the values in RDM or not.
-        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
-
-    Returns
-    -------
-    p : float
-        The permutation test result, p-value.
-    """
-
-    # get number of conditions
-    cons = np.shape(RDM1)[0]
-
-    # calculate the number of value above the diagonal in RDM
-    n = int(cons*(cons-1)/2)
-
-    v1 = np.zeros([n], dtype=np.float64)
-    v2 = np.zeros([n], dtype=np.float64)
-
-    cons = np.shape(RDM1)[0]
-
-    if rescale == True:
-
-        # flatten the RDM1
-        vrdm = np.reshape(RDM1, [cons*cons])
-        # array -> set -> list
-        svrdm = set(vrdm)
-        lvrdm = list(svrdm)
-        lvrdm.sort()
-
-        # get max & min
-        maxvalue = lvrdm[-1]
-        minvalue = lvrdm[1]
-
-        # rescale
-        if maxvalue != minvalue:
-
-            for i in range(cons):
-                for j in range(cons):
-
-                    # not on the diagnal
-                    if i != j:
-                        RDM1[i, j] = float((RDM1[i, j] - minvalue) / (maxvalue - minvalue))
-
-        # flatten the RDM2
-        vrdm = np.reshape(RDM2, [cons * cons])
-        # array -> set -> list
-        svrdm = set(vrdm)
-        lvrdm = list(svrdm)
-        lvrdm.sort()
-
-        # get max & min
-        maxvalue = lvrdm[-1]
-        minvalue = lvrdm[1]
-
-        # rescale
-        if maxvalue != minvalue:
-
-            for i in range(cons):
-                for j in range(cons):
-
-                    # not on the diagnal
-                    if i != j:
-                        RDM2[i, j] = float((RDM2[i, j] - minvalue) / (maxvalue - minvalue))
-
-    # initialize two vectors to store the values above the diagnal of two RDMs
-    v1 = np.zeros([n], dtype=np.float64)
-    v2 = np.zeros([n], dtype=np.float64)
-
-    # assignment
-    nn = 0
-    for i in range(cons - 1):
-        for j in range(cons - 1 - i):
-            v1[nn] = RDM1[i, i + j + 1]
-            v2[nn] = RDM2[i, i + j + 1]
-            nn = nn + 1
-
-    # permutation test
-
-    diff = abs(np.average(v1) - np.average(v2))
-    v = np.hstack((v1, v2))
-    print(v)
-    nv = v.shape[0]
-    ni = 0
-
-    for i in range(iter):
-        vshuffle = np.random.permutation(v)
-        vshuffle1 = vshuffle[:int(nv/2)]
-        vshuffle2 = vshuffle[int(nv/2):]
-        diff_i = abs(np.average(vshuffle1) - np.average(vshuffle2))
-
-        if diff_i >= diff:
-            ni = ni + 1
-
-    # permunitation test p-value
-    p = ni/iter
-
-    return p
